
The following command is supposed to append command current line to the history:

```s
history -s "whatever command line"
```

However, when used in shell function invoked on completion (see `@/exe/argrelay_rc.bash`),
it removes the last command in the history. Why?
    